@@ -74,9 +74,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13/coverage.info',
+ 'COVERAGE_INFO': '/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/python311/src/Python-3.11.14/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13/lcov-report',
+ 'COVERAGE_REPORT': '/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/python311/src/Python-3.11.14/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -146,7 +146,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ATANH': 1,
  'HAVE_BIND': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
- 'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
+ 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
@@ -328,7 +328,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
- 'HAVE_LIBB2': 1,
+ 'HAVE_LIBB2': 0,
  'HAVE_LIBDB': 0,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
@@ -720,7 +720,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/usr/bin/mkdir -p',
+ 'MKDIR_P': '/usr/sbin/mkdir -p',
  'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  '
                    '_codecs  _collections  errno  _io  itertools  _sre  '
                    '_thread  time  _weakref  _abc  _functools  _locale  '
@@ -809,7 +809,7 @@ build_time_vars = {'ABIFLAGS': '',
                         './Modules/_blake2/impl/blake2s-round.h '
                         './Modules/_blake2/impl/blake2s.c '
                         './Modules/_blake2/blake2module.h ./Modules/hashlib.h',
- 'MODULE__BLAKE2_LDFLAGS': '-lb2',
+ 'MODULE__BLAKE2_LDFLAGS': '',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
@@ -1086,7 +1086,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/python311/src/Python-3.11.14',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1130,10 +1130,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/python311/src/Python-3.11.14 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/python311/src/Python-3.11.14 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1164,8 +1164,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13',
- 'abs_srcdir': '/home/builder/.cache/aurutils/sync/python311/src/Python-3.11.13',
+ 'abs_builddir': '/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/python311/src/Python-3.11.14',
+ 'abs_srcdir': '/var/lib/jenkins/workspace/Archlinux/jjgaming-aur/x86_64/Python/python311/src/Python-3.11.14',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
