@@ -22,7 +22,6 @@ NL = '\n'  # XXX: no longer used by the code below.
 NLCRE = re.compile(r'\r\n|\r|\n')
 fcre = re.compile(r'^From ', re.MULTILINE)
 NEWLINE_WITHOUT_FWSP = re.compile(r'\r\n[^ \t]|\r[^ \n\t]|\n[^ \t]')
-NEWLINE_WITHOUT_FWSP_BYTES = re.compile(br'\r\n[^ \t]|\r[^ \n\t]|\n[^ \t]')
 
 
 class Generator:
@@ -430,16 +429,7 @@ class BytesGenerator(Generator):
         # This is almost the same as the string version, except for handling
         # strings with 8bit bytes.
         for h, v in msg.raw_items():
-            folded = self.policy.fold_binary(h, v)
-            if self.policy.verify_generated_headers:
-                linesep = self.policy.linesep.encode()
-                if not folded.endswith(linesep):
-                    raise HeaderWriteError(
-                        f'folded header does not end with {linesep!r}: {folded!r}')
-                if NEWLINE_WITHOUT_FWSP_BYTES.search(folded.removesuffix(linesep)):
-                    raise HeaderWriteError(
-                        f'folded header contains newline: {folded!r}')
-            self._fp.write(folded)
+            self._fp.write(self.policy.fold_binary(h, v))
         # A blank line always separates headers from body
         self.write(self._NL)
 
